<?php

namespace Blog;



session_start();

use DI\Container;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Factory\AppFactory;
use Blog\DB\User;
use Blog\Model\Blogs;
use Blog\View\Twig;
use Blog\DB\DB;
use Blog\Model\Menu;

use Blog\Model\Blog;


require __DIR__ . '/../vendor/autoload.php';





$container = new Container();
AppFactory::setContainer($container);
$app = AppFactory::create();



$container->set('twig', function () {
    $twig = new Twig('../templates');
    return $twig;
});

$container->set(
    'db',
    function () {
        $db = new DB();
        return $db;
    }
);


function addNavbar($twig)
{
    $menu = new Menu('primary');
    $twig->addBlockVariable('primary', $menu->getLinks());
}


function addNavbar2($twig)
{
    $menu = new Menu('secondary');
    $twig->addBlockVariable('secondary', $menu->getLinks());
}

function addFooter($response)
{
    $response->getBody()->write('<div>Privacy statement | Cookie Policy | Contact</div>');
    $response->getBody()->write("</body></html>");
    return;
}


$app->get('/', function (Request $request, Response $response, array $args) {

    $blogs = new Blogs();
    $blogs = $blogs->getBlogs();



    $vars = [
        "content" => $blogs
    ];

    $twig = $this->get('twig');
    addNavbar($twig);
    addNavbar2($twig);
    $a =  $twig->render('index.html.twig', $vars);
    $response->getBody()->write($a);
    return $response;
});

$app->map(['GET', 'POST'], '/blog/create', function (Request $request, Response $response, array $args) {
    if (isset($_SESSION['username'])) {
        if ($request->getMethod() == 'GET') {
            addNavbar($response);
            if (isset($_SESSION['error'])) {
                $response->getBody()->write($_SESSION['error']);
                $response->getBody()->write('<hr/>');
                unset($_SESSION['error']);
            }

            // Opdracht : Toon reeds ingevoerde gegevens in geval van foutmelding
            $response->getBody()->write('<form action="/blog/create" method="POST">');
            $response->getBody()->write('<label for="slug">slug:</label>');
            $response->getBody()->write('<input type="text" name="slug"/><br/>');
            $response->getBody()->write('<label for="title">Titel:</label>');
            $response->getBody()->write('<input type="text" name="title"/><br/>');
            $response->getBody()->write('<label for="content">Inhoud:</label>');
            $response->getBody()->write('<textarea type="textarea" name="content"></textarea><br/>');
            $response->getBody()->write('<input type="submit"/>');
            addFooter($response);
        } else {
            $data = $request->getParsedBody();
            $blog = new Blog();

            $res = $blog->createBlog($data);
            if ($res) {
                return $response->withHeader('Location', '/')->withStatus(302);
            } else {
                $err = $blog->lastErrorMsg();
                $_SESSION['error'] = $err;
                return $response->withHeader('Location', '/blog/create')->withStatus(302);
            }
        }
    } else {
        addNavbar($response);
        $response->getBody()->write(('Please login'));
        addFooter($response);
    }
    return $response;
});

$app->get('/blog/{slug}', function (Request $request, Response $response, array $args) {
    $blogs = new Blogs();
    $blogs = $blogs->getBlog($args['slug']);
    $vars = [
        "content" => $blogs
    ];

    $twig = $this->get('twig');
    addNavbar($twig);
    $a =  $twig->render('blog.html.twig', $vars);
    $response->getBody()->write($a);

    return $response;
});

$app->get('/logout', function (Request $request, Response $response, array $args) {
    unset($_SESSION['username']);
    addNavbar($response);
    $response->getBody()->write('Logged out');
    addFooter($response);
    return $response->withHeader('Location', '/')->withStatus(302);
});

$app->map(['GET', 'POST'], '/login', function (Request $request, Response $response, array $args) {

    if ($request->getMethod() == 'GET') {
        addNavbar($response);
        $response->getBody()->write('<form action="/login" method="POST">');
        $response->getBody()->write('<label for="username">Username:</label>');
        $response->getBody()->write('<input type="text" name="username"/><br/>');
        $response->getBody()->write('<label for="password">Password:</label>');
        $response->getBody()->write('<input type="password" name="password"/><br/>');
        $response->getBody()->write('<input type="submit"/>');
        addFooter($response);
    } else {
        $postdata = $request->getParsedBody();

        $user = new User();
        $logged_in = $user->checkUserPass($postdata['username'], $postdata['password']);
        if ($logged_in) {
            //if ($postdata['username'] == 'gebruiker' && $postdata['password'] == "abcd") {
            $_SESSION["username"] = $postdata['username'];
            addNavbar($response);
            $response->getBody()->write('Logged in');
            addFooter($response);
            return $response->withHeader('Location', '/')->withStatus(302);
        } else {
            $response->getBody()->write('Username and/or password incorrect');
        }
    }
    return $response;
});

$app->post('/postcomment', function (Request $request, Response $response, array $args) {
    $response->getBody()->write("Postcomment");
    return $response;
});



$app->run();
